@@ -17,10 +17,11 @@ pub use transport::websocket::{
 use crate::endpoint::validators::DEFAULT_VALIDATORS_PER_PAGE;
 use crate::endpoint::*;
 use crate::paging::Paging;
+use crate::prelude::*;
 use crate::query::Query;
 use crate::{Error, Order, SimpleRequest};
 use async_trait::async_trait;
-use std::time::Duration;
+use core::time::Duration;
 use tendermint::abci::{self, Transaction};
 use tendermint::block::Height;
 use tendermint::evidence::Evidence;
@@ -85,6 +86,18 @@ pub trait Client {
         self.perform(block_results::Request::default()).await
     }
 
+    /// `/block_search`: search for blocks by BeginBlock and EndBlock events.
+    async fn block_search(
+        &self,
+        query: Query,
+        page: u32,
+        per_page: u8,
+        order: Order,
+    ) -> Result<block_search::Response, Error> {
+        self.perform(block_search::Request::new(query, page, per_page, order))
+            .await
+    }
+
     /// `/blockchain`: get block headers for `min` <= `height` <= `max`.
     ///
     /// Block headers are returned in descending order (highest first).
